@@ -1,5 +1,5 @@
 /*
- * Copyright 2006-2018 the original author or authors.
+ * Copyright 2006-2019 the original author or authors.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -15,9 +15,7 @@
  */
 package org.objenesis;
 
-import org.junit.Rule;
 import org.junit.Test;
-import org.junit.rules.ExpectedException;
 import org.objenesis.instantiator.ObjectInstantiator;
 import org.objenesis.strategy.InstantiatorStrategy;
 
@@ -28,9 +26,6 @@ import static org.junit.Assert.*;
  */
 public class ObjenesisTest {
 
-   @Rule
-   public ExpectedException expectedException = ExpectedException.none();
-
    @Test
    public final void testObjenesis() {
       Objenesis o = new ObjenesisStd();
@@ -70,8 +65,7 @@ public class ObjenesisTest {
    @Test
    public final void testGetInstantiatorOf_primitive() {
       Objenesis o = new ObjenesisStd();
-      expectedException.expect(IllegalArgumentException.class);
-      o.getInstantiatorOf(long.class);
+      assertThrows(IllegalArgumentException.class, () -> o.getInstantiatorOf(long.class));
    }
 
    @Test
